% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/captures.r
\name{captures}
\alias{captures}
\title{Get captures}
\usage{
captures(
  x,
  onlyAnimal = TRUE,
  class = NULL,
  species = NULL,
  start = NULL,
  end = NULL,
  orders = "\%Y/\%m/\%d",
  subset = NULL,
  by = NULL
)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{onlyAnimal}{\code{logical}, defaults to \code{TRUE}, indicating whether or not to only focus on \code{observationType == "animal"}}

\item{class}{\code{character} string with the class of species to compute the captures for (e.g. "Mammalia"), defaults to NULL}

\item{species}{an optional \code{character} vector with name of the species (e.g. "Ocelot") to focus on, defaults to \code{NULL}}

\item{start}{\code{character} datetime: sequences are kept when the start of the sequences is > start, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{end}{\code{character} datetime: sequences are kept when the start of the sequences is < end, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{orders}{\code{character} string with the orders passed on to \code{\link{parse_date_time}}, defaults to "Ymd"}

\item{subset}{arguments used for filtering}

\item{by}{an optional \code{character} vector specifying the column names by which to group analyses, defaults to \code{NULL}}
}
\value{
a \code{tibble} with counts per species (with columns added: "observationType","class","order", as well as the columns specified in \code{by}).
}
\description{
Get captures
}
\examples{
\dontrun{
captures(camsample)
captures(camsample, class = "Mammalia")
captures(camsample, species = c("CollaredPeccary","OCELOT"))
captures(camsample, by = "locationName")
captures(camsample, species = c("CollaredPeccary","OCELOT"), by = "locationName")
captures(camsample, start = "2017/4/1", end = "2017/8/1")
captures(camsample, by = "locationName", subset = str_sub(locationName, 5, 5) == "3")
}
}
\seealso{
\code{\link{ctdp}},\code{\link{taxon_id}},  \code{\link{filter_timerange}}
}
\author{
Henjo de Knegt
}
