% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/check_deployments.r
\name{check_deployments}
\alias{check_deployments}
\title{Check integrity of deployments}
\usage{
check_deployments(x, duration_threshold = 20 * 7, sea_threshold = -6)
}
\arguments{
\item{x}{a \code{ctdp} object}

\item{duration_threshold}{the threshold duration, in days, above which deployments are flagged}

\item{sea_threshold}{the sun elevation angle, in degrees, above the horizon below which deployment start/end are flagged}
}
\value{
a \code{tibble} with information columns:
\itemize{
  \item \code{deploymentID}: identifier
  \item \code{nr_false}: the number of validity check columns (see below) that contain value FALSE
  \item \code{deployment_interval}: interval
  \item \code{longitude,latitude}: lon/lat coordinates
  \item \code{locationName}: name
  \item \code{seq_start,seq_end}: timestamp of the first/last sequence in the deployment
  \item \code{duration}: duration (in days) of the deployment
  \item \code{sea_start,sea_end}: solar elevation angle (in degrees above horizon) at the time of start/end of deployment
  \item \code{dt_start,dt_end}: time difference (in days) between start/end of deployment and seq_start,seq_end
}
as well as validity check columns (prefix "ok_"):
\itemize{
  \item \code{start,end}: no NAs
  \item \code{startend}: end > start (thus length > 0 sec)
  \item \code{lon,lat}: no NAs
  \item \code{name}: no NAs
  \item \code{sea_start,sea_end}: start/end of deployment when sun is >= sea_threshold
  \item \code{duration}: difference between duration (days) <= duration_threshold
}
}
\description{
Check integrity of deployments
}
\seealso{
NULL
\dontrun{
test <- check_deployments(camsample)
test %>% filter(nr_false > 0)
}
}
\author{
Henjo de Knegt
}
