% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/as_ctdp.r, R/ctdp_package.r, R/distinct.r,
%   R/print.ctdp.r, R/read_ctdp.r
\docType{package}
\name{as_ctdp}
\alias{as_ctdp}
\alias{ctdp}
\alias{distinct.ctdp}
\alias{print.ctdp}
\alias{read_ctdp}
\title{Convert a camtraptor object to ctdp object}
\usage{
as_ctdp(
  x,
  tz = "Etc/GMT-2",
  verbose = TRUE,
  rmEmpty = FALSE,
  pathInfo = NULL,
  dropMedia = FALSE
)

\method{distinct}{ctdp}(x)

\method{print}{ctdp}(x)

read_ctdp(
  path,
  tz = "Etc/GMT-2",
  verbose = TRUE,
  rmEmpty = FALSE,
  dropMedia = FALSE
)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{tz}{\code{character} string with time-zone code, defaults to \code{"Etc/GMT-2"}. See \code{\link{set_GMT_offset}}}

\item{verbose}{\code{logical}, defaults to \code{TRUE}: printing information on progress}

\item{rmEmpty}{\code{logical}, defaults to \code{TRUE}: remove columns that only contain NAs}

\item{pathInfo}{file path information internally called from \code{\link{read_ctdp}}}

\item{dropMedia}{\code{logical}, defaults to \code{FALSE}: whether or not to drop the media tibble.}

\item{path}{\code{character} string with the path to the folder or zip-file holding the data}
}
\value{
an object of class \code{\link{ctdp}}.

an object of class \code{\link{ctdp}}

an object of class \code{ctdp}, which is a \code{list} with elements:
\itemize{
  \item \code{locations}: a \code{tibble} with info on camera locations
  \item \code{deployments}: a \code{tibble} with info on deployments
  \item \code{sequences}: a \code{tibble} with info on sequences
  \item \code{observations}: a \code{tibble} with info on observations
  \item \code{media}: a \code{tibble} with info on captured images
  \item \code{taxonomy}: a \code{tibble} with the used taxonomy table
  \item \code{settings}: a \code{list} with settings, including the path to the folder or file with source data, time zone, whether or not the object holds timestamps as \code{Interval} objects, and whether or not the object contains the media information.
}
}
\description{
Convert a camtraptor object to ctdp object

ctdp - a package to work with camtrap-dp data

Remove duplicate records from the tables of a ctdp object

This function loads a frictionless datapackage into an object of class \code{ctdp}, using the 'frictionless' and 'camtraptor' packages (see \url{https://inbo.github.io/camtraptor/} and \url{https://docs.ropensci.org/frictionless/}).
}
\details{
Converts an object from the \code{camtraptor} package (see \url{https://inbo.github.io/camtraptor/} and \url{https://docs.ropensci.org/frictionless/}) to a \code{\link{ctdp}} object
}
\section{Methods (by generic)}{
\itemize{
\item \code{distinct(ctdp)}: Remove duplicate records from the tables of a ctdp object

}}
\section{Functions}{
\itemize{
\item \code{as_ctdp()}: Convert a camtraptor object to ctdp object

}}
\examples{
NULL
\dontrun{
distinct(camsample)
}
\dontrun{
  data(camsample)
  camsample
}
}
\seealso{
\code{\link{read_ctdp}}, \code{\link{read_camtrap_dp}}

\code{\link{ctdp}}

\code{\link{as_ctdp}}
}
\author{
Henjo de Knegt
}
