% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ctdp_periods.r
\name{ctdp_periods}
\alias{ctdp_periods}
\title{Slice deployments with periods}
\usage{
ctdp_periods(x, y)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{y}{a \code{tibble} with columns "name" and "interval": (e.g. the result of function \code{\link{set_periods}})}
}
\value{
an object of class \code{\link{ctdp}}
}
\description{
Slice deployments with periods
}
\examples{
\dontrun{
# get overall time range of data
time_range(camsample)
plot_time_coverage(camsample)

# Set period intervals
periods <- set_periods(start = c("4-21 08:00", "6-21 08:00"),
                       end   = c("5-19 18:00", "7-19 18:00"), 
                       orders = "md HM",
                       years = 2017,
                       tz = "Etc/GMT+5")

# Slice the ctdp object
y <- ctdp_periods(camsample, periods)
y
y$deployments
y$deployments \%>\% count(periodName)
plot_time_coverage(y)

# Process further
y <- filter_deployments(y, !is.na(periodName))
y
plot_time_coverage(y)
}
}
\seealso{
\code{\link{set_periods}}
}
\author{
Henjo de Knegt
}
