% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fraction_annotated.r
\name{fraction_annotated}
\alias{fraction_annotated}
\title{Compute the fraction of sequences that is annotated}
\usage{
fraction_annotated(
  x,
  onlyMotion = TRUE,
  omitSetupType = TRUE,
  start = NULL,
  end = NULL,
  orders = "\%Y/\%m/\%d",
  subset = NULL,
  by = NULL
)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{onlyMotion}{\code{logical}, whether or not to only use motion detection images, defaults to \code{TRUE}}

\item{omitSetupType}{\code{logical}, whether or not to omit sequences that are marked as some form of setup (`observations` column `cameraSetupType` is than not NA), defaults to \code{TRUE}}

\item{start}{\code{character} datetime: sequences are kept when the start of the sequences is > start, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{end}{\code{character} datetime: sequences are kept when the start of the sequences is < end, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{orders}{\code{character} string with the orders passed on to \code{\link{parse_date_time}}, defaults to "Ymd"}

\item{subset}{arguments used for filtering}

\item{by}{an optional \code{character} vector specifying the column names by which to group analyses, defaults to \code{NULL}}
}
\value{
a tibble with summary data per deployment (or group specified in \code{by}), with columns:
\itemize{
  \item deploymentID, or columns specified in \code{by}
  \item fracAnnotated: the fraction of all sequences in this group that have been annotated (observationType != "unclassified")
  \item nrSeqs: number of sequences in this group (optionally after filter for only motion detection)
  \item nrSeqsAnnotated: number of annotated sequences in this group (optionally after filter for only motion detection)
  \item nrPhotos: number of photos in this group (optionally after filter for only motion detection)
}
}
\description{
Compute the fraction of sequences that is annotated
}
\examples{
\dontrun{
fraction_annotated(camsample)
fraction_annotated(camsample, by = "locationName")
fraction_annotated(camsample, by = "transect")
fraction_annotated(camsample, start = "2017/4/1", end = "2017/8/1")
fraction_annotated(camsample, by = "locationName", subset = str_sub(locationName, 5, 5) == "3")
}
}
\seealso{
\code{\link{ctdp}}
}
\author{
Henjo de Knegt
}
