% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_time_coverage.r
\name{plot_time_coverage}
\alias{plot_time_coverage}
\title{Plot activity of the camera-stations over time}
\usage{
plot_time_coverage(
  x,
  IDcol = "locationName",
  xlab = "Time",
  ylab = "Location",
  grouping = NULL,
  colour = NULL,
  dynamic = TRUE,
  addSequences = FALSE,
  jitter = 0.05,
  size = 0.25,
  doTimelapse = FALSE,
  doPlot = TRUE
)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{IDcol}{\code{character} name of the column that groups the deployments, defaults to "locationName}

\item{xlab, ylab}{\code{character} names of the axis labels (defaults to "Time" and "Location")}

\item{grouping}{an optional \code{character} vector with the name(s) of the grouping columns, defaults to \code{NULL}}

\item{colour}{an optional \code{character} name of the column in the deployments table to be used for colouring the polygons (this overwrites the \code{grouping} argument, which will then only be used for the y-axis ordering). Defaults to \code{NULL}}

\item{dynamic}{\code{logical} whether or not to plot a dynamic graph (via \code{ggplotly}, defaults to \code{TRUE}}

\item{addSequences}{\code{logical} whether or not to add the times of sequences to the plots (with jittering in y-direction), defaults to \code{FALSE}}

\item{jitter}{\code{numeric} value of the amount of vertical jittering (sd of normal distribution centered on 0), defaults to 0.05.}

\item{size}{\code{numeric} value of the size of the points, defaults to 0.25}

\item{doTimelapse}{\code{logical} whether or not to plot the time lapse sequences, defaults to \code{FALSE}}

\item{doPlot}{\code{logical} whether or not to plot, defaults to \code{TRUE}}
}
\value{
invisibly returns the plot
}
\description{
Plot activity of the camera-stations over time
}
\examples{
\dontrun{
# dynamic ggplotly plots
plot_time_coverage(camsample)
plot_time_coverage(camsample, addSequences = TRUE)

# only ggplot
plot_time_coverage(camsample, dynamic = FALSE)
plot_time_coverage(camsample, addSequences = TRUE, dynamic = FALSE)

# colour by grouping
plot_time_coverage(camsample, grouping = "transect")
}
}
\seealso{
\code{\link{ctdp}}
}
\author{
Henjo de Knegt
}
