% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/summarise_deployments.r
\name{summarise_deployments}
\alias{summarise_deployments}
\title{Summarize (groups of) deployments}
\usage{
summarise_deployments(
  x,
  datatable = FALSE,
  onlyMotion = TRUE,
  omitSetupType = TRUE,
  start = NULL,
  end = NULL,
  orders = "\%Y/\%m/\%d",
  subset = NULL,
  by = NULL
)
}
\arguments{
\item{x}{an object of class \code{\link{ctdp}}}

\item{datatable}{\code{logical}, whether or not to show as interactive datatable in the viewer, defaults to \code{FALSE}}

\item{onlyMotion}{\code{logical}, whether or not to only use motion detection images, defaults to \code{TRUE}}

\item{omitSetupType}{\code{logical}, whether or not to omit sequences that are marked as some form of setup (`observations` column `cameraSetupType` is than not NA), defaults to \code{TRUE}}

\item{start}{\code{character} datetime: sequences are kept when the start of the sequences is > start, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{end}{\code{character} datetime: sequences are kept when the start of the sequences is < end, passed on to \code{\link{parse_date_time}}. Defaults to \code{NULL}}

\item{orders}{\code{character} string with the orders passed on to \code{\link{parse_date_time}}, defaults to "Ymd"}

\item{subset}{arguments used for filtering}

\item{by}{an optional \code{character} vector specifying the column names by which to group analyses, defaults to \code{NULL}}
}
\value{
a \code{tibble} like returned by \code{\link{fraction_annotated}}, but with extra column "effort", which contains the total number of camera-trap days for each group (row)
}
\description{
Summarize (groups of) deployments
}
\examples{
\dontrun{
summarise_deployments(camsample)
summarise_deployments(camsample, by = "locationName")
summarise_deployments(camsample, by = "transect")
summarise_deployments(camsample, start = "2017/4/1", end = "2017/8/1")
summarise_deployments(camsample, by = "locationName", subset = str_sub(locationName, 5, 5) == "3") 

# As datatable in viewer
summarise_deployments(camsample, datatable = TRUE)
}
}
\seealso{
\code{\link{fraction_annotated}}
}
\author{
Henjo de Knegt
}
